Index: src/variables.h |
diff --git a/src/variables.h b/src/variables.h |
index 401d04446379784708a41c32c2b575050b59a54e..51b7362d4620c48d6a3873c2af25eb822282c3de 100644 |
--- a/src/variables.h |
+++ b/src/variables.h |
@@ -77,7 +77,7 @@ class Variable: public ZoneObject { |
Variable(Scope* scope, |
Handle<String> name, |
VariableMode mode, |
- bool is_valid_lhs, |
+ bool is_valid_ref, |
Kind kind, |
InitializationFlag initialization_flag, |
Interface* interface = Interface::NewValue()); |
@@ -85,7 +85,7 @@ class Variable: public ZoneObject { |
// Printing support |
static const char* Mode2String(VariableMode mode); |
- bool IsValidLeftHandSide() { return is_valid_LHS_; } |
+ bool IsValidReference() { return is_valid_ref_; } |
// The source code for an eval() call may refer to a variable that is |
// in an outer scope about which we don't know anything (it may not |
@@ -172,8 +172,8 @@ class Variable: public ZoneObject { |
// binding scope (exclusive). |
Variable* local_if_not_shadowed_; |
- // Valid as a LHS? (const and this are not valid LHS, for example) |
- bool is_valid_LHS_; |
+ // Valid as a reference? (const and this are not valid, for example) |
+ bool is_valid_ref_; |
// Usage info. |
bool force_context_allocation_; // set by variable resolver |